@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-10-13'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-12-07'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -141,7 +141,7 @@ sub munge_files {
             code_before_instantiate_cmdline => $code_before_instantiate_cmdline,
             code_after_end => $code_after_end,
             config_filename => $self->config_filename,
-            (subcommand => $subcommands) x !!$subcommands,
+            (subcommands => $subcommands) x !!$subcommands,
             subcommands_from_package_functions => $self->subcommands_from_package_functions,
             (include_package_functions_match => $self->include_package_functions_match) x !!$self->include_package_functions_match,
             (exclude_package_functions_match => $self->exclude_package_functions_match) x !!$self->exclude_package_functions_match,
@@ -226,7 +226,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.27 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-10-13.
+This document describes version 0.28 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-12-07.
 
 =head1 SYNOPSIS
 
